==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/KpiAliasArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The KPI alias.
 * @property aliasName KPI alias name.
 * @property expression The expression.
 */
public data class KpiAliasArgs(
    public val aliasName: Output<String>,
    public val expression: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs> {
    override fun toJava(): com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs =
        com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs.builder()
            .aliasName(aliasName.applyValue({ args0 -> args0 }))
            .expression(expression.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KpiAliasArgs].
 */
@PulumiTagMarker
public class KpiAliasArgsBuilder internal constructor() {
    private var aliasName: Output<String>? = null

    private var expression: Output<String>? = null

    /**
     * @param value KPI alias name.
     */
    @JvmName("vynyvfkubwsgjuoa")
    public suspend fun aliasName(`value`: Output<String>) {
        this.aliasName = value
    }

    /**
     * @param value The expression.
     */
    @JvmName("gtjsqyvdbrtbtkju")
    public suspend fun expression(`value`: Output<String>) {
        this.expression = value
    }

    /**
     * @param value KPI alias name.
     */
    @JvmName("mekmjlxbldmioarf")
    public suspend fun aliasName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.aliasName = mapped
    }

    /**
     * @param value The expression.
     */
    @JvmName("uunnnbktdiyjedno")
    public suspend fun expression(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.expression = mapped
    }

    internal fun build(): KpiAliasArgs = KpiAliasArgs(
        aliasName = aliasName ?: throw PulumiNullFieldException("aliasName"),
        expression = expression ?: throw PulumiNullFieldException("expression"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/KpiAliasArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The KPI alias.
 * @property aliasName KPI alias name.
 * @property expression The expression.
 */
public data class KpiAliasArgs(
    public val aliasName: Output<String>,
    public val expression: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs> {
    override fun toJava(): com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs =
        com.pulumi.azurenative.customerinsights.inputs.KpiAliasArgs.builder()
            .aliasName(aliasName.applyValue({ args0 -> args0 }))
            .expression(expression.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KpiAliasArgs].
 */
@PulumiTagMarker
public class KpiAliasArgsBuilder internal constructor() {
    private var aliasName: Output<String>? = null

    private var expression: Output<String>? = null

    /**
     * @param value KPI alias name.
     */
    @JvmName("mrspjbiyxybrvujg")
    public suspend fun aliasName(`value`: Output<String>) {
        this.aliasName = value
    }

    /**
     * @param value The expression.
     */
    @JvmName("fhcymfnhmfmqltdy")
    public suspend fun expression(`value`: Output<String>) {
        this.expression = value
    }

    /**
     * @param value KPI alias name.
     */
    @JvmName("rkybsaryppvlbxxb")
    public suspend fun aliasName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.aliasName = mapped
    }

    /**
     * @param value The expression.
     */
    @JvmName("ldujlhaffkwtderi")
    public suspend fun expression(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.expression = mapped
    }

    internal fun build(): KpiAliasArgs = KpiAliasArgs(
        aliasName = aliasName ?: throw PulumiNullFieldException("aliasName"),
        expression = expression ?: throw PulumiNullFieldException("expression"),
    )
}
